( cd usr/bin ; rm -rf wish )
( cd usr/bin ; ln -sf wish4.1 wish )
( cd usr/lib ; rm -rf libtk.so )
( cd usr/lib ; ln -sf libtk.so.1 libtk.so )
( cd usr/lib ; rm -rf libtk.so.1 )
( cd usr/lib ; ln -sf libtk.so.1.4.1 libtk.so.1 )
( cd usr/man/mann ; rm -rf tk_bindForTraversal.n.gz )
( cd usr/man/mann ; ln -sf menubar.n.gz tk_bindForTraversal.n.gz )
( cd usr/man/mann ; rm -rf tk_bisque.n.gz )
( cd usr/man/mann ; ln -sf palette.n.gz tk_bisque.n.gz )
( cd usr/man/mann ; rm -rf tk_dialog.n.gz )
( cd usr/man/mann ; ln -sf dialog.n.gz tk_dialog.n.gz )
( cd usr/man/mann ; rm -rf tk_focusFollowsMouse.n.gz )
( cd usr/man/mann ; ln -sf focusNext.n.gz tk_focusFollowsMouse.n.gz )
( cd usr/man/mann ; rm -rf tk_focusNext.n.gz )
( cd usr/man/mann ; ln -sf focusNext.n.gz tk_focusNext.n.gz )
( cd usr/man/mann ; rm -rf tk_focusPrev.n.gz )
( cd usr/man/mann ; ln -sf focusNext.n.gz tk_focusPrev.n.gz )
( cd usr/man/mann ; rm -rf tk_menuBar.n.gz )
( cd usr/man/mann ; ln -sf menubar.n.gz tk_menuBar.n.gz )
( cd usr/man/mann ; rm -rf tk_optionMenu.n.gz )
( cd usr/man/mann ; ln -sf optionMenu.n.gz tk_optionMenu.n.gz )
( cd usr/man/mann ; rm -rf tk_popup.n.gz )
( cd usr/man/mann ; ln -sf popup.n.gz tk_popup.n.gz )
( cd usr/man/mann ; rm -rf tk_setPalette.n.gz )
( cd usr/man/mann ; ln -sf palette.n.gz tk_setPalette.n.gz )
( cd usr/man/man3 ; rm -rf Tk_3DBorderColor.3.gz )
( cd usr/man/man3 ; ln -sf 3DBorder.3.gz Tk_3DBorderColor.3.gz )
( cd usr/man/man3 ; rm -rf Tk_3DBorderGC.3.gz )
( cd usr/man/man3 ; ln -sf 3DBorder.3.gz Tk_3DBorderGC.3.gz )
( cd usr/man/man3 ; rm -rf Tk_3DHorizontalBevel.3.gz )
( cd usr/man/man3 ; ln -sf 3DBorder.3.gz Tk_3DHorizontalBevel.3.gz )
( cd usr/man/man3 ; rm -rf Tk_3DVerticalBevel.3.gz )
( cd usr/man/man3 ; ln -sf 3DBorder.3.gz Tk_3DVerticalBevel.3.gz )
( cd usr/man/man3 ; rm -rf Tk_Attributes.3.gz )
( cd usr/man/man3 ; ln -sf WindowId.3.gz Tk_Attributes.3.gz )
( cd usr/man/man3 ; rm -rf Tk_BindEvent.3.gz )
( cd usr/man/man3 ; ln -sf BindTable.3.gz Tk_BindEvent.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CanvasDrawableCoords.3.gz )
( cd usr/man/man3 ; ln -sf CanvTkwin.3.gz Tk_CanvasDrawableCoords.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CanvasEventuallyRedraw.3.gz )
( cd usr/man/man3 ; ln -sf CanvTkwin.3.gz Tk_CanvasEventuallyRedraw.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CanvasGetCoord.3.gz )
( cd usr/man/man3 ; ln -sf CanvTkwin.3.gz Tk_CanvasGetCoord.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CanvasPsBitmap.3.gz )
( cd usr/man/man3 ; ln -sf CanvPsY.3.gz Tk_CanvasPsBitmap.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CanvasPsColor.3.gz )
( cd usr/man/man3 ; ln -sf CanvPsY.3.gz Tk_CanvasPsColor.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CanvasPsFont.3.gz )
( cd usr/man/man3 ; ln -sf CanvPsY.3.gz Tk_CanvasPsFont.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CanvasPsPath.3.gz )
( cd usr/man/man3 ; ln -sf CanvPsY.3.gz Tk_CanvasPsPath.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CanvasPsStipple.3.gz )
( cd usr/man/man3 ; ln -sf CanvPsY.3.gz Tk_CanvasPsStipple.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CanvasPsY.3.gz )
( cd usr/man/man3 ; ln -sf CanvPsY.3.gz Tk_CanvasPsY.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CanvasSetStippleOrigin.3.gz )
( cd usr/man/man3 ; ln -sf CanvTkwin.3.gz Tk_CanvasSetStippleOrigin.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CanvasTagsOption.3.gz )
( cd usr/man/man3 ; ln -sf CanvTkwin.3.gz Tk_CanvasTagsOption.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CanvasTextInfo.3.gz )
( cd usr/man/man3 ; ln -sf CanvTxtInfo.3.gz Tk_CanvasTextInfo.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CanvasTkwin.3.gz )
( cd usr/man/man3 ; ln -sf CanvTkwin.3.gz Tk_CanvasTkwin.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CanvasWindowCoords.3.gz )
( cd usr/man/man3 ; ln -sf CanvTkwin.3.gz Tk_CanvasWindowCoords.3.gz )
( cd usr/man/man3 ; rm -rf Tk_ChangeWindowAttributes.3.gz )
( cd usr/man/man3 ; ln -sf ConfigWind.3.gz Tk_ChangeWindowAttributes.3.gz )
( cd usr/man/man3 ; rm -rf Tk_Changes.3.gz )
( cd usr/man/man3 ; ln -sf WindowId.3.gz Tk_Changes.3.gz )
( cd usr/man/man3 ; rm -rf Tk_Class.3.gz )
( cd usr/man/man3 ; ln -sf SetClass.3.gz Tk_Class.3.gz )
( cd usr/man/man3 ; rm -rf Tk_ClearSelection.3.gz )
( cd usr/man/man3 ; ln -sf ClrSelect.3.gz Tk_ClearSelection.3.gz )
( cd usr/man/man3 ; rm -rf Tk_ClipboardAppend.3.gz )
( cd usr/man/man3 ; ln -sf Clipboard.3.gz Tk_ClipboardAppend.3.gz )
( cd usr/man/man3 ; rm -rf Tk_ClipboardClear.3.gz )
( cd usr/man/man3 ; ln -sf Clipboard.3.gz Tk_ClipboardClear.3.gz )
( cd usr/man/man3 ; rm -rf Tk_Colormap.3.gz )
( cd usr/man/man3 ; ln -sf WindowId.3.gz Tk_Colormap.3.gz )
( cd usr/man/man3 ; rm -rf Tk_ConfigureInfo.3.gz )
( cd usr/man/man3 ; ln -sf ConfigWidg.3.gz Tk_ConfigureInfo.3.gz )
( cd usr/man/man3 ; rm -rf Tk_ConfigureValue.3.gz )
( cd usr/man/man3 ; ln -sf ConfigWidg.3.gz Tk_ConfigureValue.3.gz )
( cd usr/man/man3 ; rm -rf Tk_ConfigureWidget.3.gz )
( cd usr/man/man3 ; ln -sf ConfigWidg.3.gz Tk_ConfigureWidget.3.gz )
( cd usr/man/man3 ; rm -rf Tk_ConfigureWindow.3.gz )
( cd usr/man/man3 ; ln -sf ConfigWind.3.gz Tk_ConfigureWindow.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CoordsToWindow.3.gz )
( cd usr/man/man3 ; ln -sf CoordToWin.3.gz Tk_CoordsToWindow.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CreateBinding.3.gz )
( cd usr/man/man3 ; ln -sf BindTable.3.gz Tk_CreateBinding.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CreateBindingTable.3.gz )
( cd usr/man/man3 ; ln -sf BindTable.3.gz Tk_CreateBindingTable.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CreateErrorHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtErrHdlr.3.gz Tk_CreateErrorHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CreateEventHandler.3.gz )
( cd usr/man/man3 ; ln -sf EventHndlr.3.gz Tk_CreateEventHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CreateGenericHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtGenHdlr.3.gz Tk_CreateGenericHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CreateImageType.3.gz )
( cd usr/man/man3 ; ln -sf CrtImgType.3.gz Tk_CreateImageType.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CreateItemType.3.gz )
( cd usr/man/man3 ; ln -sf CrtItemType.3.gz Tk_CreateItemType.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CreatePhotoImageFormat.3.gz )
( cd usr/man/man3 ; ln -sf CrtPhImgFmt.3.gz Tk_CreatePhotoImageFormat.3.gz )
( cd usr/man/man3 ; rm -rf Tk_CreateSelHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtSelHdlr.3.gz Tk_CreateSelHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tk_DefineBitmap.3.gz )
( cd usr/man/man3 ; ln -sf GetBitmap.3.gz Tk_DefineBitmap.3.gz )
( cd usr/man/man3 ; rm -rf Tk_DefineCursor.3.gz )
( cd usr/man/man3 ; ln -sf ConfigWind.3.gz Tk_DefineCursor.3.gz )
( cd usr/man/man3 ; rm -rf Tk_DeleteAllBindings.3.gz )
( cd usr/man/man3 ; ln -sf BindTable.3.gz Tk_DeleteAllBindings.3.gz )
( cd usr/man/man3 ; rm -rf Tk_DeleteBinding.3.gz )
( cd usr/man/man3 ; ln -sf BindTable.3.gz Tk_DeleteBinding.3.gz )
( cd usr/man/man3 ; rm -rf Tk_DeleteBindingTable.3.gz )
( cd usr/man/man3 ; ln -sf BindTable.3.gz Tk_DeleteBindingTable.3.gz )
( cd usr/man/man3 ; rm -rf Tk_DeleteErrorHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtErrHdlr.3.gz Tk_DeleteErrorHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tk_DeleteEventHandler.3.gz )
( cd usr/man/man3 ; ln -sf EventHndlr.3.gz Tk_DeleteEventHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tk_DeleteGenericHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtGenHdlr.3.gz Tk_DeleteGenericHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tk_DeleteImage.3.gz )
( cd usr/man/man3 ; ln -sf DeleteImg.3.gz Tk_DeleteImage.3.gz )
( cd usr/man/man3 ; rm -rf Tk_DeleteSelHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtSelHdlr.3.gz Tk_DeleteSelHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tk_Depth.3.gz )
( cd usr/man/man3 ; ln -sf WindowId.3.gz Tk_Depth.3.gz )
( cd usr/man/man3 ; rm -rf Tk_Display.3.gz )
( cd usr/man/man3 ; ln -sf WindowId.3.gz Tk_Display.3.gz )
( cd usr/man/man3 ; rm -rf Tk_DisplayName.3.gz )
( cd usr/man/man3 ; ln -sf WindowId.3.gz Tk_DisplayName.3.gz )
( cd usr/man/man3 ; rm -rf Tk_Draw3DPolygon.3.gz )
( cd usr/man/man3 ; ln -sf 3DBorder.3.gz Tk_Draw3DPolygon.3.gz )
( cd usr/man/man3 ; rm -rf Tk_Draw3DRectangle.3.gz )
( cd usr/man/man3 ; ln -sf 3DBorder.3.gz Tk_Draw3DRectangle.3.gz )
( cd usr/man/man3 ; rm -rf Tk_DrawFocusHighlight.3.gz )
( cd usr/man/man3 ; ln -sf DrawFocHlt.3.gz Tk_DrawFocusHighlight.3.gz )
( cd usr/man/man3 ; rm -rf Tk_Fill3DPolygon.3.gz )
( cd usr/man/man3 ; ln -sf 3DBorder.3.gz Tk_Fill3DPolygon.3.gz )
( cd usr/man/man3 ; rm -rf Tk_Fill3DRectangle.3.gz )
( cd usr/man/man3 ; ln -sf 3DBorder.3.gz Tk_Fill3DRectangle.3.gz )
( cd usr/man/man3 ; rm -rf Tk_FindPhoto.3.gz )
( cd usr/man/man3 ; ln -sf FindPhoto.3.gz Tk_FindPhoto.3.gz )
( cd usr/man/man3 ; rm -rf Tk_Free3DBorder.3.gz )
( cd usr/man/man3 ; ln -sf 3DBorder.3.gz Tk_Free3DBorder.3.gz )
( cd usr/man/man3 ; rm -rf Tk_FreeBitmap.3.gz )
( cd usr/man/man3 ; ln -sf GetBitmap.3.gz Tk_FreeBitmap.3.gz )
( cd usr/man/man3 ; rm -rf Tk_FreeColor.3.gz )
( cd usr/man/man3 ; ln -sf GetColor.3.gz Tk_FreeColor.3.gz )
( cd usr/man/man3 ; rm -rf Tk_FreeColormap.3.gz )
( cd usr/man/man3 ; ln -sf GetClrmap.3.gz Tk_FreeColormap.3.gz )
( cd usr/man/man3 ; rm -rf Tk_FreeCursor.3.gz )
( cd usr/man/man3 ; ln -sf GetCursor.3.gz Tk_FreeCursor.3.gz )
( cd usr/man/man3 ; rm -rf Tk_FreeFontStruct.3.gz )
( cd usr/man/man3 ; ln -sf GetFontStr.3.gz Tk_FreeFontStruct.3.gz )
( cd usr/man/man3 ; rm -rf Tk_FreeGC.3.gz )
( cd usr/man/man3 ; ln -sf GetGC.3.gz Tk_FreeGC.3.gz )
( cd usr/man/man3 ; rm -rf Tk_FreeImage.3.gz )
( cd usr/man/man3 ; ln -sf GetImage.3.gz Tk_FreeImage.3.gz )
( cd usr/man/man3 ; rm -rf Tk_FreeOptions.3.gz )
( cd usr/man/man3 ; ln -sf ConfigWidg.3.gz Tk_FreeOptions.3.gz )
( cd usr/man/man3 ; rm -rf Tk_FreePixmap.3.gz )
( cd usr/man/man3 ; ln -sf GetPixmap.3.gz Tk_FreePixmap.3.gz )
( cd usr/man/man3 ; rm -rf Tk_FreeXId.3.gz )
( cd usr/man/man3 ; ln -sf FreeXId.3.gz Tk_FreeXId.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GeometryRequest.3.gz )
( cd usr/man/man3 ; ln -sf GeomReq.3.gz Tk_GeometryRequest.3.gz )
( cd usr/man/man3 ; rm -rf Tk_Get3DBorder.3.gz )
( cd usr/man/man3 ; ln -sf 3DBorder.3.gz Tk_Get3DBorder.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetAllBindings.3.gz )
( cd usr/man/man3 ; ln -sf BindTable.3.gz Tk_GetAllBindings.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetAnchor.3.gz )
( cd usr/man/man3 ; ln -sf GetAnchor.3.gz Tk_GetAnchor.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetAtomName.3.gz )
( cd usr/man/man3 ; ln -sf InternAtom.3.gz Tk_GetAtomName.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetBinding.3.gz )
( cd usr/man/man3 ; ln -sf BindTable.3.gz Tk_GetBinding.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetBitmap.3.gz )
( cd usr/man/man3 ; ln -sf GetBitmap.3.gz Tk_GetBitmap.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetBitmapFromData.3.gz )
( cd usr/man/man3 ; ln -sf GetBitmap.3.gz Tk_GetBitmapFromData.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetCapStyle.3.gz )
( cd usr/man/man3 ; ln -sf GetCapStyl.3.gz Tk_GetCapStyle.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetColor.3.gz )
( cd usr/man/man3 ; ln -sf GetColor.3.gz Tk_GetColor.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetColorByValue.3.gz )
( cd usr/man/man3 ; ln -sf GetColor.3.gz Tk_GetColorByValue.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetColormap.3.gz )
( cd usr/man/man3 ; ln -sf GetClrmap.3.gz Tk_GetColormap.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetCursor.3.gz )
( cd usr/man/man3 ; ln -sf GetCursor.3.gz Tk_GetCursor.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetCursorFromData.3.gz )
( cd usr/man/man3 ; ln -sf GetCursor.3.gz Tk_GetCursorFromData.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetFontStruct.3.gz )
( cd usr/man/man3 ; ln -sf GetFontStr.3.gz Tk_GetFontStruct.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetGC.3.gz )
( cd usr/man/man3 ; ln -sf GetGC.3.gz Tk_GetGC.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetImage.3.gz )
( cd usr/man/man3 ; ln -sf GetImage.3.gz Tk_GetImage.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetItemTypes.3.gz )
( cd usr/man/man3 ; ln -sf CrtItemType.3.gz Tk_GetItemTypes.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetJoinStyle.3.gz )
( cd usr/man/man3 ; ln -sf GetJoinStl.3.gz Tk_GetJoinStyle.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetJustify.3.gz )
( cd usr/man/man3 ; ln -sf GetJustify.3.gz Tk_GetJustify.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetOption.3.gz )
( cd usr/man/man3 ; ln -sf GetOption.3.gz Tk_GetOption.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetPixels.3.gz )
( cd usr/man/man3 ; ln -sf GetPixels.3.gz Tk_GetPixels.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetPixmap.3.gz )
( cd usr/man/man3 ; ln -sf GetPixmap.3.gz Tk_GetPixmap.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetRelief.3.gz )
( cd usr/man/man3 ; ln -sf GetRelief.3.gz Tk_GetRelief.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetRootCoords.3.gz )
( cd usr/man/man3 ; ln -sf GetRootCrd.3.gz Tk_GetRootCoords.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetScreenMM.3.gz )
( cd usr/man/man3 ; ln -sf GetPixels.3.gz Tk_GetScreenMM.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetScrollInfo.3.gz )
( cd usr/man/man3 ; ln -sf GetScroll.3.gz Tk_GetScrollInfo.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetSelection.3.gz )
( cd usr/man/man3 ; ln -sf GetSelect.3.gz Tk_GetSelection.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetUid.3.gz )
( cd usr/man/man3 ; ln -sf GetUid.3.gz Tk_GetUid.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetVRootGeometry.3.gz )
( cd usr/man/man3 ; ln -sf GetVRoot.3.gz Tk_GetVRootGeometry.3.gz )
( cd usr/man/man3 ; rm -rf Tk_GetVisual.3.gz )
( cd usr/man/man3 ; ln -sf GetVisual.3.gz Tk_GetVisual.3.gz )
( cd usr/man/man3 ; rm -rf Tk_HandleEvent.3.gz )
( cd usr/man/man3 ; ln -sf HandleEvent.3.gz Tk_HandleEvent.3.gz )
( cd usr/man/man3 ; rm -rf Tk_Height.3.gz )
( cd usr/man/man3 ; ln -sf WindowId.3.gz Tk_Height.3.gz )
( cd usr/man/man3 ; rm -rf Tk_IdToWindow.3.gz )
( cd usr/man/man3 ; ln -sf IdToWindow.3.gz Tk_IdToWindow.3.gz )
( cd usr/man/man3 ; rm -rf Tk_ImageChanged.3.gz )
( cd usr/man/man3 ; ln -sf ImgChanged.3.gz Tk_ImageChanged.3.gz )
( cd usr/man/man3 ; rm -rf Tk_InternAtom.3.gz )
( cd usr/man/man3 ; ln -sf InternAtom.3.gz Tk_InternAtom.3.gz )
( cd usr/man/man3 ; rm -rf Tk_InternalBorderWidth.3.gz )
( cd usr/man/man3 ; ln -sf WindowId.3.gz Tk_InternalBorderWidth.3.gz )
( cd usr/man/man3 ; rm -rf Tk_IsMapped.3.gz )
( cd usr/man/man3 ; ln -sf WindowId.3.gz Tk_IsMapped.3.gz )
( cd usr/man/man3 ; rm -rf Tk_IsTopLevel.3.gz )
( cd usr/man/man3 ; ln -sf WindowId.3.gz Tk_IsTopLevel.3.gz )
( cd usr/man/man3 ; rm -rf Tk_MainLoop.3.gz )
( cd usr/man/man3 ; ln -sf MainLoop.3.gz Tk_MainLoop.3.gz )
( cd usr/man/man3 ; rm -rf Tk_MainWindow.3.gz )
( cd usr/man/man3 ; ln -sf MainWin.3.gz Tk_MainWindow.3.gz )
( cd usr/man/man3 ; rm -rf Tk_MaintainGeometry.3.gz )
( cd usr/man/man3 ; ln -sf MaintGeom.3.gz Tk_MaintainGeometry.3.gz )
( cd usr/man/man3 ; rm -rf Tk_ManageGeometry.3.gz )
( cd usr/man/man3 ; ln -sf ManageGeom.3.gz Tk_ManageGeometry.3.gz )
( cd usr/man/man3 ; rm -rf Tk_MapWindow.3.gz )
( cd usr/man/man3 ; ln -sf MapWindow.3.gz Tk_MapWindow.3.gz )
( cd usr/man/man3 ; rm -rf Tk_MoveResizeWindow.3.gz )
( cd usr/man/man3 ; ln -sf ConfigWind.3.gz Tk_MoveResizeWindow.3.gz )
( cd usr/man/man3 ; rm -rf Tk_MoveToplevelWindow.3.gz )
( cd usr/man/man3 ; ln -sf MoveToplev.3.gz Tk_MoveToplevelWindow.3.gz )
( cd usr/man/man3 ; rm -rf Tk_MoveWindow.3.gz )
( cd usr/man/man3 ; ln -sf ConfigWind.3.gz Tk_MoveWindow.3.gz )
( cd usr/man/man3 ; rm -rf Tk_Name.3.gz )
( cd usr/man/man3 ; ln -sf Name.3.gz Tk_Name.3.gz )
( cd usr/man/man3 ; rm -rf Tk_NameOf3DBorder.3.gz )
( cd usr/man/man3 ; ln -sf 3DBorder.3.gz Tk_NameOf3DBorder.3.gz )
( cd usr/man/man3 ; rm -rf Tk_NameOfAnchor.3.gz )
( cd usr/man/man3 ; ln -sf GetAnchor.3.gz Tk_NameOfAnchor.3.gz )
( cd usr/man/man3 ; rm -rf Tk_NameOfBitmap.3.gz )
( cd usr/man/man3 ; ln -sf GetBitmap.3.gz Tk_NameOfBitmap.3.gz )
( cd usr/man/man3 ; rm -rf Tk_NameOfCapStyle.3.gz )
( cd usr/man/man3 ; ln -sf GetCapStyl.3.gz Tk_NameOfCapStyle.3.gz )
( cd usr/man/man3 ; rm -rf Tk_NameOfColor.3.gz )
( cd usr/man/man3 ; ln -sf GetColor.3.gz Tk_NameOfColor.3.gz )
( cd usr/man/man3 ; rm -rf Tk_NameOfCursor.3.gz )
( cd usr/man/man3 ; ln -sf GetCursor.3.gz Tk_NameOfCursor.3.gz )
( cd usr/man/man3 ; rm -rf Tk_NameOfFontStruct.3.gz )
( cd usr/man/man3 ; ln -sf GetFontStr.3.gz Tk_NameOfFontStruct.3.gz )
( cd usr/man/man3 ; rm -rf Tk_NameOfImage.3.gz )
( cd usr/man/man3 ; ln -sf NameOfImg.3.gz Tk_NameOfImage.3.gz )
( cd usr/man/man3 ; rm -rf Tk_NameOfJoinStyle.3.gz )
( cd usr/man/man3 ; ln -sf GetJoinStl.3.gz Tk_NameOfJoinStyle.3.gz )
( cd usr/man/man3 ; rm -rf Tk_NameOfJustify.3.gz )
( cd usr/man/man3 ; ln -sf GetJustify.3.gz Tk_NameOfJustify.3.gz )
( cd usr/man/man3 ; rm -rf Tk_NameOfRelief.3.gz )
( cd usr/man/man3 ; ln -sf GetRelief.3.gz Tk_NameOfRelief.3.gz )
( cd usr/man/man3 ; rm -rf Tk_NameToWindow.3.gz )
( cd usr/man/man3 ; ln -sf Name.3.gz Tk_NameToWindow.3.gz )
( cd usr/man/man3 ; rm -rf Tk_Offset.3.gz )
( cd usr/man/man3 ; ln -sf ConfigWidg.3.gz Tk_Offset.3.gz )
( cd usr/man/man3 ; rm -rf Tk_OwnSelection.3.gz )
( cd usr/man/man3 ; ln -sf OwnSelect.3.gz Tk_OwnSelection.3.gz )
( cd usr/man/man3 ; rm -rf Tk_Parent.3.gz )
( cd usr/man/man3 ; ln -sf WindowId.3.gz Tk_Parent.3.gz )
( cd usr/man/man3 ; rm -rf Tk_ParseArgv.3.gz )
( cd usr/man/man3 ; ln -sf ParseArgv.3.gz Tk_ParseArgv.3.gz )
( cd usr/man/man3 ; rm -rf Tk_PathName.3.gz )
( cd usr/man/man3 ; ln -sf Name.3.gz Tk_PathName.3.gz )
( cd usr/man/man3 ; rm -rf Tk_PhotoBlank.3.gz )
( cd usr/man/man3 ; ln -sf FindPhoto.3.gz Tk_PhotoBlank.3.gz )
( cd usr/man/man3 ; rm -rf Tk_PhotoExpand.3.gz )
( cd usr/man/man3 ; ln -sf FindPhoto.3.gz Tk_PhotoExpand.3.gz )
( cd usr/man/man3 ; rm -rf Tk_PhotoGetImage.3.gz )
( cd usr/man/man3 ; ln -sf FindPhoto.3.gz Tk_PhotoGetImage.3.gz )
( cd usr/man/man3 ; rm -rf Tk_PhotoGetSize.3.gz )
( cd usr/man/man3 ; ln -sf FindPhoto.3.gz Tk_PhotoGetSize.3.gz )
( cd usr/man/man3 ; rm -rf Tk_PhotoPutBlock.3.gz )
( cd usr/man/man3 ; ln -sf FindPhoto.3.gz Tk_PhotoPutBlock.3.gz )
( cd usr/man/man3 ; rm -rf Tk_PhotoPutZoomedBlock.3.gz )
( cd usr/man/man3 ; ln -sf FindPhoto.3.gz Tk_PhotoPutZoomedBlock.3.gz )
( cd usr/man/man3 ; rm -rf Tk_PhotoSetSize.3.gz )
( cd usr/man/man3 ; ln -sf FindPhoto.3.gz Tk_PhotoSetSize.3.gz )
( cd usr/man/man3 ; rm -rf Tk_QueueWindowEvent.3.gz )
( cd usr/man/man3 ; ln -sf QWinEvent.3.gz Tk_QueueWindowEvent.3.gz )
( cd usr/man/man3 ; rm -rf Tk_RedrawImage.3.gz )
( cd usr/man/man3 ; ln -sf GetImage.3.gz Tk_RedrawImage.3.gz )
( cd usr/man/man3 ; rm -rf Tk_ReqHeight.3.gz )
( cd usr/man/man3 ; ln -sf WindowId.3.gz Tk_ReqHeight.3.gz )
( cd usr/man/man3 ; rm -rf Tk_ReqWidth.3.gz )
( cd usr/man/man3 ; ln -sf WindowId.3.gz Tk_ReqWidth.3.gz )
( cd usr/man/man3 ; rm -rf Tk_ResizeWindow.3.gz )
( cd usr/man/man3 ; ln -sf ConfigWind.3.gz Tk_ResizeWindow.3.gz )
( cd usr/man/man3 ; rm -rf Tk_RestackWindow.3.gz )
( cd usr/man/man3 ; ln -sf Restack.3.gz Tk_RestackWindow.3.gz )
( cd usr/man/man3 ; rm -rf Tk_RestrictEvents.3.gz )
( cd usr/man/man3 ; ln -sf RestrictEv.3.gz Tk_RestrictEvents.3.gz )
( cd usr/man/man3 ; rm -rf Tk_Screen.3.gz )
( cd usr/man/man3 ; ln -sf WindowId.3.gz Tk_Screen.3.gz )
( cd usr/man/man3 ; rm -rf Tk_ScreenNumber.3.gz )
( cd usr/man/man3 ; ln -sf WindowId.3.gz Tk_ScreenNumber.3.gz )
( cd usr/man/man3 ; rm -rf Tk_SetAppName.3.gz )
( cd usr/man/man3 ; ln -sf SetAppName.3.gz Tk_SetAppName.3.gz )
( cd usr/man/man3 ; rm -rf Tk_SetBackgroundFromBorder.3.gz )
( cd usr/man/man3 ; ln -sf 3DBorder.3.gz Tk_SetBackgroundFromBorder.3.gz )
( cd usr/man/man3 ; rm -rf Tk_SetClass.3.gz )
( cd usr/man/man3 ; ln -sf SetClass.3.gz Tk_SetClass.3.gz )
( cd usr/man/man3 ; rm -rf Tk_SetGrid.3.gz )
( cd usr/man/man3 ; ln -sf SetGrid.3.gz Tk_SetGrid.3.gz )
( cd usr/man/man3 ; rm -rf Tk_SetInternalBorder.3.gz )
( cd usr/man/man3 ; ln -sf GeomReq.3.gz Tk_SetInternalBorder.3.gz )
( cd usr/man/man3 ; rm -rf Tk_SetWindowBackground.3.gz )
( cd usr/man/man3 ; ln -sf ConfigWind.3.gz Tk_SetWindowBackground.3.gz )
( cd usr/man/man3 ; rm -rf Tk_SetWindowBackgroundPixmap.3.gz )
( cd usr/man/man3 ; ln -sf ConfigWind.3.gz Tk_SetWindowBackgroundPixmap.3.gz )
( cd usr/man/man3 ; rm -rf Tk_SetWindowBorder.3.gz )
( cd usr/man/man3 ; ln -sf ConfigWind.3.gz Tk_SetWindowBorder.3.gz )
( cd usr/man/man3 ; rm -rf Tk_SetWindowBorderPixmap.3.gz )
( cd usr/man/man3 ; ln -sf ConfigWind.3.gz Tk_SetWindowBorderPixmap.3.gz )
( cd usr/man/man3 ; rm -rf Tk_SetWindowBorderWidth.3.gz )
( cd usr/man/man3 ; ln -sf ConfigWind.3.gz Tk_SetWindowBorderWidth.3.gz )
( cd usr/man/man3 ; rm -rf Tk_SetWindowColormap.3.gz )
( cd usr/man/man3 ; ln -sf ConfigWind.3.gz Tk_SetWindowColormap.3.gz )
( cd usr/man/man3 ; rm -rf Tk_SetWindowVisual.3.gz )
( cd usr/man/man3 ; ln -sf SetVisual.3.gz Tk_SetWindowVisual.3.gz )
( cd usr/man/man3 ; rm -rf Tk_SizeOfBitmap.3.gz )
( cd usr/man/man3 ; ln -sf GetBitmap.3.gz Tk_SizeOfBitmap.3.gz )
( cd usr/man/man3 ; rm -rf Tk_SizeOfImage.3.gz )
( cd usr/man/man3 ; ln -sf GetImage.3.gz Tk_SizeOfImage.3.gz )
( cd usr/man/man3 ; rm -rf Tk_StrictMotif.3.gz )
( cd usr/man/man3 ; ln -sf StrictMotif.3.gz Tk_StrictMotif.3.gz )
( cd usr/man/man3 ; rm -rf Tk_Uid.3.gz )
( cd usr/man/man3 ; ln -sf GetUid.3.gz Tk_Uid.3.gz )
( cd usr/man/man3 ; rm -rf Tk_UndefineCursor.3.gz )
( cd usr/man/man3 ; ln -sf ConfigWind.3.gz Tk_UndefineCursor.3.gz )
( cd usr/man/man3 ; rm -rf Tk_UnmaintainGeometry.3.gz )
( cd usr/man/man3 ; ln -sf MaintGeom.3.gz Tk_UnmaintainGeometry.3.gz )
( cd usr/man/man3 ; rm -rf Tk_UnmapWindow.3.gz )
( cd usr/man/man3 ; ln -sf MapWindow.3.gz Tk_UnmapWindow.3.gz )
( cd usr/man/man3 ; rm -rf Tk_UnsetGrid.3.gz )
( cd usr/man/man3 ; ln -sf SetGrid.3.gz Tk_UnsetGrid.3.gz )
( cd usr/man/man3 ; rm -rf Tk_Visual.3.gz )
( cd usr/man/man3 ; ln -sf WindowId.3.gz Tk_Visual.3.gz )
( cd usr/man/man3 ; rm -rf Tk_Width.3.gz )
( cd usr/man/man3 ; ln -sf WindowId.3.gz Tk_Width.3.gz )
( cd usr/man/man3 ; rm -rf Tk_WindowId.3.gz )
( cd usr/man/man3 ; ln -sf WindowId.3.gz Tk_WindowId.3.gz )
( cd usr/man/man3 ; rm -rf Tk_X.3.gz )
( cd usr/man/man3 ; ln -sf WindowId.3.gz Tk_X.3.gz )
( cd usr/man/man3 ; rm -rf Tk_Y.3.gz )
( cd usr/man/man3 ; ln -sf WindowId.3.gz Tk_Y.3.gz )
